==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/RuleBuilder.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RuleBuilder extends RuleFluentImpl<RuleBuilder> implements VisitableBuilder<Rule,RuleBuilder>{
  public RuleBuilder() {
    this(false);
  }
  public RuleBuilder(Boolean validationEnabled) {
    this(new Rule(), validationEnabled);
  }
  public RuleBuilder(RuleFluent<?> fluent) {
    this(fluent, false);
  }
  public RuleBuilder(RuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Rule(), validationEnabled);
  }
  public RuleBuilder(RuleFluent<?> fluent,Rule instance) {
    this(fluent, instance, false);
  }
  public RuleBuilder(RuleFluent<?> fluent,Rule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
      fluent.withWhen(instance.getWhen());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RuleBuilder(Rule instance) {
    this(instance,false);
  }
  public RuleBuilder(Rule instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
      this.withWhen(instance.getWhen());
    }
    this.validationEnabled = validationEnabled; 
  }
  RuleFluent<?> fluent;
  Boolean validationEnabled;
  public Rule build() {
    Rule buildable = new Rule(fluent.getFrom(),fluent.getTo(),fluent.getWhen());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/security/v1beta1/RuleBuilder.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RuleBuilder extends RuleFluent<RuleBuilder> implements VisitableBuilder<Rule,RuleBuilder>{
  public RuleBuilder() {
    this(false);
  }
  public RuleBuilder(Boolean validationEnabled) {
    this(new Rule(), validationEnabled);
  }
  public RuleBuilder(RuleFluent<?> fluent) {
    this(fluent, false);
  }
  public RuleBuilder(RuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Rule(), validationEnabled);
  }
  public RuleBuilder(RuleFluent<?> fluent,Rule instance) {
    this(fluent, instance, false);
  }
  public RuleBuilder(RuleFluent<?> fluent,Rule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Rule());

    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
      fluent.withWhen(instance.getWhen());
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
      fluent.withWhen(instance.getWhen());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RuleBuilder(Rule instance) {
    this(instance,false);
  }
  public RuleBuilder(Rule instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Rule());

    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
      this.withWhen(instance.getWhen());
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
      this.withWhen(instance.getWhen());
    }
    this.validationEnabled = validationEnabled; 
  }
  RuleFluent<?> fluent;
  Boolean validationEnabled;
  public Rule build() {
    Rule buildable = new Rule(fluent.buildFrom(),fluent.buildTo(),fluent.buildWhen());
    return buildable;
  }
  
}
